set_current_thread_in_threadpool

Function set_current_thread_in_threadpool 

pub fn set_current_thread_in_threadpool()
Mark the current thread as part of a thread pool for mimalloc.

This is a safe wrapper around mimalloc V3’s mi_thread_set_in_threadpool. The upstream API takes no pointers, only updates the current thread’s mimalloc thread-local state, and is intended to be called by custom thread-pool worker threads. Repeated calls keep the same threadpool marker.